==> haskell-conduit-1.3.6.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit
version:              1.3.6.1
visibility:           public
id:                   conduit-1.3.6.1-xf7BUYu4FPC4jaCDr8wkD
key:                  conduit-1.3.6.1-xf7BUYu4FPC4jaCDr8wkD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  5cbec14fcea918ff61c46fd9c54d6f2d
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit
hs-libraries:         HSconduit-1.3.6.1-xf7BUYu4FPC4jaCDr8wkD
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    mono-traversable-1.0.21.0-5eiav6ZTu3X66acTrT0ZAb mtl-2.2.2
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.6.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit
version:              1.3.6.1
visibility:           public
id:                   conduit-1.3.6.1-IZ8OSXmnRyPK1N2pz1JDDM
key:                  conduit-1.3.6.1-IZ8OSXmnRyPK1N2pz1JDDM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  9b55c8e0170248370cfd52866a70e923
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit
hs-libraries:         HSconduit-1.3.6.1-IZ8OSXmnRyPK1N2pz1JDDM
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    mono-traversable-1.0.21.0-9bSFpWJ0Bot6REIJQ7Nk9J mtl-2.2.2
    primitive-0.8.0.0-GOwpVXsLqFV9QZOjtUgUYN
    resourcet-1.2.6-IGynvl9svIK6TArSccG3vI text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.1.0-KSX0XQMPS0MKwOGi5hYJAY

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
